==> dtlpy-1.45.10-py3-none-any.whl: dtlpy/entities/__init__.py <==
#! /usr/bin/env python3
# This file is part of DTLPY.
#
# DTLPY is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DTLPY is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DTLPY.  If not, see <http://www.gnu.org/licenses/>.
from . import package_defaults
from .annotation_definitions import BaseAnnotationDefinition
from .base_entity import BaseEntity
from .item import Item, ItemStatus, Modality, ModalityTypeEnum, ModalityRefTypeEnum
from .links import Link, ItemLink, UrlLink, LinkTypeEnum
from .trigger import Trigger, TriggerResource, TriggerAction, TriggerExecutionMode, BaseTrigger, CronTrigger, \
    TriggerType
from .project import Project, MemberRole
from .artifact import Artifact
from .dataset import Dataset, ExpirationOptions
from .codebase import Codebase
from .annotation import Annotation, FrameAnnotation, ViewAnnotationOptions, AnnotationStatus, AnnotationType
from .annotation_collection import AnnotationCollection
from .paged_entities import PagedEntities
from .filters import Filters, FiltersKnownFields, FiltersResource, FiltersOperations, FiltersMethod, \
    FiltersOrderByDirection
from .recipe import Recipe
from .ontology import Ontology
from .annotation_definitions import Box, Cube, Cube3d, Point, Segmentation, Polygon, Ellipse, Classification, \
    Subtitle, Text, \
    Polyline, Comparison, UndefinedAnnotationType, Note, Description, Pose
from .label import Label
from .codebase import Codebase, PackageCodebaseType, ItemCodebase, GitCodebase, FilesystemCodebase, LocalCodebase
from .package import Package
from .package_module import PackageModule
from .package_slot import PackageSlot, SlotPostAction, SlotPostActionType, SlotDisplayScope, SlotDisplayScopeResource
from .package_function import PackageFunction, FunctionIO, PackageInputType
from .time_series import TimeSeries
from .service import Service, KubernetesAutuscalerType, KubernetesRabbitmqAutoscaler, KubernetesAutoscaler, \
    InstanceCatalog, KubernetesRuntime
from .execution import Execution, ExecutionStatus
from .command import Command, CommandsStatus
from .assignment import Assignment, Workload, WorkloadUnit
from .task import Task, ItemAction
from .directory_tree import DirectoryTree
from .similarity import Similarity, MultiView, SimilarityItem, MultiViewItem, SimilarityTypeEnum
from .user import User
from .bot import Bot
from .webhook import Webhook, HttpMethod
from .model import Model, ModelOutputType, ModelInputType
from .snapshot import Snapshot, OntologySpec, SnapshotPartitionType
from .bucket import BucketType, Bucket, ItemBucket, GCSBucket, LocalBucket
from .driver import Driver
from .pipeline import Pipeline, PipelineConnection, PipelineNode, PipelineConnectionPort, PipelineNodeIO
from .pipeline_execution import PipelineExecution, PipelineExecutionNode
from .feature import Feature
from .feature_set import FeatureSet, FeatureEntityType
from .organization import Organization, OrganizationsPlans, MemberOrgRole
from .integration import Integration
from .driver import Driver, ExternalStorage

==> dtlpy-1.47.10-py3-none-any.whl: dtlpy/entities/__init__.py <==
#! /usr/bin/env python3
# This file is part of DTLPY.
#
# DTLPY is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DTLPY is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DTLPY.  If not, see <http://www.gnu.org/licenses/>.
from . import package_defaults
from .annotation_definitions import BaseAnnotationDefinition
from .base_entity import BaseEntity
from .item import Item, ItemStatus, Modality, ModalityTypeEnum, ModalityRefTypeEnum
from .links import Link, ItemLink, UrlLink, LinkTypeEnum
from .trigger import Trigger, TriggerResource, TriggerAction, TriggerExecutionMode, BaseTrigger, CronTrigger, \
    TriggerType
from .project import Project, MemberRole
from .artifact import Artifact
from .dataset import Dataset, ExpirationOptions
from .codebase import Codebase
from .annotation import Annotation, FrameAnnotation, ViewAnnotationOptions, AnnotationStatus, AnnotationType
from .annotation_collection import AnnotationCollection
from .paged_entities import PagedEntities
from .filters import Filters, FiltersKnownFields, FiltersResource, FiltersOperations, FiltersMethod, \
    FiltersOrderByDirection
from .recipe import Recipe
from .ontology import Ontology
from .annotation_definitions import Box, Cube, Cube3d, Point, Segmentation, Polygon, Ellipse, Classification, \
    Subtitle, Text, \
    Polyline, Comparison, UndefinedAnnotationType, Note, Description, Pose
from .label import Label
from .codebase import Codebase, PackageCodebaseType, ItemCodebase, GitCodebase, FilesystemCodebase, LocalCodebase
from .package import Package, RequirementOperator, PackageRequirement
from .package_module import PackageModule
from .package_slot import PackageSlot, SlotPostAction, SlotPostActionType, SlotDisplayScope, SlotDisplayScopeResource
from .package_function import PackageFunction, FunctionIO, PackageInputType
from .time_series import TimeSeries
from .service import Service, KubernetesAutuscalerType, KubernetesRabbitmqAutoscaler, KubernetesAutoscaler, \
    InstanceCatalog, KubernetesRuntime
from .execution import Execution, ExecutionStatus
from .command import Command, CommandsStatus
from .assignment import Assignment, Workload, WorkloadUnit
from .task import Task, ItemAction
from .directory_tree import DirectoryTree
from .similarity import Similarity, MultiView, SimilarityItem, MultiViewItem, SimilarityTypeEnum
from .user import User
from .bot import Bot
from .webhook import Webhook, HttpMethod
from .model import Model, ModelOutputType, ModelInputType
from .snapshot import Snapshot, OntologySpec, SnapshotPartitionType
from .bucket import BucketType, Bucket, ItemBucket, GCSBucket, LocalBucket
from .driver import Driver
from .pipeline import Pipeline, PipelineConnection, PipelineNode, PipelineConnectionPort, PipelineNodeIO
from .pipeline_execution import PipelineExecution, PipelineExecutionNode
from .feature import Feature
from .feature_set import FeatureSet, FeatureEntityType
from .organization import Organization, OrganizationsPlans, MemberOrgRole
from .integration import Integration
from .driver import Driver, ExternalStorage
